@@ -714,10 +714,10 @@ class Column:
                     value['check_with'] = ip_address.__name__
 
             if self._data.column_name == "email":
-                from colemen_utilities.validate_utils.cerberus import email
-                value['check_with'] = email
+                from colemen_utilities.validate_utils.cerberus import is_email
+                value['check_with'] = is_email
                 if force_function_names is True:
-                    value['check_with'] = ip_address.__name__
+                    value['check_with'] = is_email.__name__
 
             if self._data.is_hash_id:
                 max_nonce = self._data.character_maximum_length - len(self._data.hash_id_prefix)
